@@ -8,7 +8,7 @@ CHANGELOG = """%(debian_name)s (%(version)s-1) UNRELEASED; urgency=low
 
 CONTROL = """Source: %(Source)s
 Section: web
-Priority: extra
+Priority: optional
 Maintainer: Debian Javascript Maintainers <pkg-javascript-devel@lists.alioth.debian.org>
 Uploaders: %(Uploaders)s
 Build-Depends:
@@ -19,7 +19,6 @@ Standards-Version: %(Standards-Version)s
 Homepage: %(Homepage)s
 Vcs-Git: %(Vcs-Git)s
 Vcs-Browser: %(Vcs-Browser)s
-XS-Testsuite: autopkgtest
 
 Package: %(Package)s
 Architecture: all
